@@ -15,8 +15,6 @@
 
 
 import collections
-import logging
-import os
 import unicodedata
 
 
@@ -45,7 +43,6 @@ class BasicTokenizer(object):
 
     def __init__(self, do_lower_case=True, never_split=None, tokenize_chinese_chars=True):
         """ Constructs a BasicTokenizer.
-
         Args:
             **do_lower_case**: Whether to lower case the input.
             **never_split**: (`optional`) list of str
@@ -66,7 +63,6 @@ class BasicTokenizer(object):
     def tokenize(self, text, never_split=None):
         """ Basic Tokenization of a piece of text.
             Split on "white spaces" only, for sub-word tokenization, see WordPieceTokenizer.
-
         Args:
             **never_split**: (`optional`) list of str
                 Kept for backward compatibility purposes.
@@ -151,14 +147,14 @@ class BasicTokenizer(object):
         # space-separated words, so they are not treated specially and handled
         # like the all of the other languages.
         if (
-            (cp >= 0x4E00 and cp <= 0x9FFF)
-            or (cp >= 0x3400 and cp <= 0x4DBF)
-            or (cp >= 0x20000 and cp <= 0x2A6DF)  #
-            or (cp >= 0x2A700 and cp <= 0x2B73F)  #
-            or (cp >= 0x2B740 and cp <= 0x2B81F)  #
-            or (cp >= 0x2B820 and cp <= 0x2CEAF)  #
-            or (cp >= 0xF900 and cp <= 0xFAFF)
-            or (cp >= 0x2F800 and cp <= 0x2FA1F)  #
+                (cp >= 0x4E00 and cp <= 0x9FFF)
+                or (cp >= 0x3400 and cp <= 0x4DBF)
+                or (cp >= 0x20000 and cp <= 0x2A6DF)  #
+                or (cp >= 0x2A700 and cp <= 0x2B73F)  #
+                or (cp >= 0x2B740 and cp <= 0x2B81F)  #
+                or (cp >= 0x2B820 and cp <= 0x2CEAF)  #
+                or (cp >= 0xF900 and cp <= 0xFAFF)
+                or (cp >= 0x2F800 and cp <= 0x2FA1F)  #
         ):  #
             return True
 
@@ -188,18 +184,14 @@ class WordpieceTokenizer(object):
 
     def tokenize(self, text):
         """Tokenizes a piece of text into its word pieces.
-
         This uses a greedy longest-match-first algorithm to perform tokenization
         using the given vocabulary.
-
         For example:
           input = "unaffable"
           output = ["un", "##aff", "##able"]
-
         Args:
           text: A single token or whitespace separated tokens. This should have
             already been passed through `BasicTokenizer`.
-
         Returns:
           A list of wordpiece tokens.
         """
@@ -274,4 +266,4 @@ def _is_punctuation(char):
     cat = unicodedata.category(char)
     if cat.startswith("P"):
         return True
-    return False
+    return False
\ No newline at end of file
